@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,10 +33,12 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
+
 from google.cloud.shell_v1.types import cloudshell
-from .transports.base import CloudShellServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import CloudShellServiceGrpcAsyncIOTransport
+
 from .client import CloudShellServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, CloudShellServiceTransport
+from .transports.grpc_asyncio import CloudShellServiceGrpcAsyncIOTransport
 
 
 class CloudShellServiceAsyncClient:
@@ -225,14 +227,13 @@ class CloudShellServiceAsyncClient:
         r"""Gets an environment. Returns NOT_FOUND if the environment does
         not exist.
 
-
         .. code-block:: python
 
             from google.cloud import shell_v1
 
-            def sample_get_environment():
+            async def sample_get_environment():
                 # Create a client
-                client = shell_v1.CloudShellServiceClient()
+                client = shell_v1.CloudShellServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = shell_v1.GetEnvironmentRequest(
@@ -240,7 +241,7 @@ class CloudShellServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_environment(request=request)
+                response = await client.get_environment(request=request)
 
                 # Handle the response
                 print(response)
@@ -301,7 +302,8 @@ class CloudShellServiceAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    core_exceptions.ServiceUnavailable, core_exceptions.Unknown,
+                    core_exceptions.ServiceUnavailable,
+                    core_exceptions.Unknown,
                 ),
                 deadline=60.0,
             ),
@@ -316,7 +318,12 @@ class CloudShellServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -338,14 +345,13 @@ class CloudShellServiceAsyncClient:
         connections, the operation will contain a
         StartEnvironmentResponse in its response field.
 
-
         .. code-block:: python
 
             from google.cloud import shell_v1
 
-            def sample_start_environment():
+            async def sample_start_environment():
                 # Create a client
-                client = shell_v1.CloudShellServiceClient()
+                client = shell_v1.CloudShellServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = shell_v1.StartEnvironmentRequest(
@@ -356,7 +362,7 @@ class CloudShellServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -398,7 +404,12 @@ class CloudShellServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -425,14 +436,13 @@ class CloudShellServiceAsyncClient:
         line tools without requiring the user to manually
         authenticate.
 
-
         .. code-block:: python
 
             from google.cloud import shell_v1
 
-            def sample_authorize_environment():
+            async def sample_authorize_environment():
                 # Create a client
-                client = shell_v1.CloudShellServiceClient()
+                client = shell_v1.CloudShellServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = shell_v1.AuthorizeEnvironmentRequest(
@@ -443,7 +453,7 @@ class CloudShellServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -484,7 +494,12 @@ class CloudShellServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -510,14 +525,13 @@ class CloudShellServiceAsyncClient:
         SSH. If a key with the same content already exists, this will
         error with ALREADY_EXISTS.
 
-
         .. code-block:: python
 
             from google.cloud import shell_v1
 
-            def sample_add_public_key():
+            async def sample_add_public_key():
                 # Create a client
-                client = shell_v1.CloudShellServiceClient()
+                client = shell_v1.CloudShellServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = shell_v1.AddPublicKeyRequest(
@@ -528,7 +542,7 @@ class CloudShellServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -571,7 +585,12 @@ class CloudShellServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -597,14 +616,13 @@ class CloudShellServiceAsyncClient:
         corresponding private key. If a key with the same content is not
         present, this will error with NOT_FOUND.
 
-
         .. code-block:: python
 
             from google.cloud import shell_v1
 
-            def sample_remove_public_key():
+            async def sample_remove_public_key():
                 # Create a client
-                client = shell_v1.CloudShellServiceClient()
+                client = shell_v1.CloudShellServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = shell_v1.RemovePublicKeyRequest(
@@ -615,7 +633,7 @@ class CloudShellServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -658,7 +676,12 @@ class CloudShellServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -680,7 +703,9 @@ class CloudShellServiceAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-shell",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-shell",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
