@@ -16,18 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -36,8 +36,10 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
+
 from google.cloud.shell_v1.types import cloudshell
-from .transports.base import CloudShellServiceTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, CloudShellServiceTransport
 from .transports.grpc import CloudShellServiceGrpcTransport
 from .transports.grpc_asyncio import CloudShellServiceGrpcAsyncIOTransport
 
@@ -57,7 +59,8 @@ class CloudShellServiceClientMeta(type):
     _transport_registry["grpc_asyncio"] = CloudShellServiceGrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[CloudShellServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -171,10 +174,14 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def environment_path(user: str, environment: str,) -> str:
+    def environment_path(
+        user: str,
+        environment: str,
+    ) -> str:
         """Returns a fully-qualified environment string."""
         return "users/{user}/environments/{environment}".format(
-            user=user, environment=environment,
+            user=user,
+            environment=environment,
         )
 
     @staticmethod
@@ -184,7 +191,9 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -197,9 +206,13 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -208,9 +221,13 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -219,9 +236,13 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -230,10 +251,14 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -405,6 +430,7 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
                 always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def get_environment(
@@ -419,7 +445,6 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
         r"""Gets an environment. Returns NOT_FOUND if the environment does
         not exist.
 
-
         .. code-block:: python
 
             from google.cloud import shell_v1
@@ -501,7 +526,12 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -523,7 +553,6 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
         connections, the operation will contain a
         StartEnvironmentResponse in its response field.
 
-
         .. code-block:: python
 
             from google.cloud import shell_v1
@@ -584,7 +613,12 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -611,7 +645,6 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
         line tools without requiring the user to manually
         authenticate.
 
-
         .. code-block:: python
 
             from google.cloud import shell_v1
@@ -671,7 +704,12 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -697,7 +735,6 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
         SSH. If a key with the same content already exists, this will
         error with ALREADY_EXISTS.
 
-
         .. code-block:: python
 
             from google.cloud import shell_v1
@@ -759,7 +796,12 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -785,7 +827,6 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
         corresponding private key. If a key with the same content is not
         present, this will error with NOT_FOUND.
 
-
         .. code-block:: python
 
             from google.cloud import shell_v1
@@ -847,7 +888,12 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -876,7 +922,9 @@ class CloudShellServiceClient(metaclass=CloudShellServiceClientMeta):
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("google-cloud-shell",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "google-cloud-shell",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
